import Vue from 'vue'
import Vuex from 'vuex'
import { getUser, logout, getApp } from '@/api/base'

Vue.use(Vuex)

const store = new Vuex.Store({
  state: {
    user: {},
    appid: localStorage.getItem('appid') || '',
    app: {}
  },
  mutations: {
    setUser(state, user) {
      state.user = user
    },
    setAppid(state, appid) {
      state.appid = appid
    },
    setApp(state, app) {
      state.app = app
    }
  },
  actions: {
    // 获取用户信息
    getUser({ commit }) {
      getUser().then(response => {
        commit('setUser', response)
      })
    },
    // 退出登录
    logout({ commit }) {
      return logout().then(response => {
        commit('setUser', {})
        return response
      })
    },
    async checkLogin({ commit }) {
      const isLogin = await getUser()
        .then(response => {
          if (response.code === 0) {
            commit('setUser', response.data)
            return true
          } else {
            commit('setUser', {})
            return false
          }
        })
        .catch(() => {
          commit('setUser', {})
          return false
        })
      return isLogin
    },
    getApp({ commit, state }, appid) {
      getApp(appid || state.appid).then(res => {
        commit('setApp', res.data)
      })
    }
  }
})
store.dispatch('getApp')
export default store
